@@ -113,7 +113,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 """
 import abc
 import builtins
@@ -172,20 +172,20 @@ class IotToLambdaToDynamoDB(
 
         jsii.create(IotToLambdaToDynamoDB, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> aws_cdk.aws_dynamodb.Table:
-        return jsii.get(self, "dynamoTable")
+        return typing.cast(aws_cdk.aws_dynamodb.Table, jsii.get(self, "dynamoTable"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="iotTopicRule")
     def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
-        return jsii.get(self, "iotTopicRule")
+        return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return jsii.get(self, "lambdaFunction")
+        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
 
 @jsii.data_type(
@@ -244,7 +244,7 @@ class IotToLambdaToDynamoDBProps:
         """
         result = self._values.get("iot_topic_rule_props")
         assert result is not None, "Required property 'iot_topic_rule_props' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_iot.CfnTopicRuleProps, result)
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
@@ -253,7 +253,7 @@ class IotToLambdaToDynamoDBProps:
         :default: - Default props are used
         """
         result = self._values.get("dynamo_table_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -262,7 +262,7 @@ class IotToLambdaToDynamoDBProps:
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
     @builtins.property
     def lambda_function_props(
@@ -273,7 +273,7 @@ class IotToLambdaToDynamoDBProps:
         :default: - Default props are used
         """
         result = self._values.get("lambda_function_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     @builtins.property
     def table_permissions(self) -> typing.Optional[builtins.str]:
@@ -284,7 +284,7 @@ class IotToLambdaToDynamoDBProps:
         :default: - Read/write access is given to the Lambda function if no value is specified.
         """
         result = self._values.get("table_permissions")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
